==> sagemaker_jupyterlab_emr_extension-0.2.0.tar.gz: sagemaker_jupyterlab_emr_extension-0.2.0/src/components/__tests__/SelectAuthType.spec.tsx <==
import React from 'react';
import { render } from '@testing-library/react';
import '@testing-library/jest-dom/extend-expect';
import { SelectAuthType } from '../SelectAuthType';
import { i18nStrings } from '../../constants/i18n';
import { JupyterFrontEnd } from '@jupyterlab/application';

// Mock the necessary props and functions
const eventDetailMock = 'eventDetailMock';
const app = null as unknown as JupyterFrontEnd;

jest.mock('../../utils/SelectAuthUtil', () => ({ handleConnect: jest.fn() }));

const mockProps = {
  onCloseModal: jest.fn(),
  selectedCluster: undefined,
  app: app,
  eventDetail: eventDetailMock,
  notebookPanel: undefined,
};

describe('SelectAuthType', () => {
  it('renders component with default auth type', () => {
    const { getByLabelText } = render(<SelectAuthType {...mockProps} />);

    // Ensure that the component renders with default auth type 'Basic_Access'
    expect(getByLabelText(i18nStrings.Clusters.radioButtonLabels.basicAccess)).toBeInTheDocument();
    expect(getByLabelText(i18nStrings.Clusters.radioButtonLabels.noCredential)).toBeInTheDocument();
  });

  it('renders the component with default auth type', () => {
    const { getByLabelText } = render(
      <SelectAuthType
        onCloseModal={() => {}}
        selectedCluster={undefined}
        app={app}
        eventDetail="eventDetailMock"
        notebookPanel={undefined}
      />,
    );

    const basicAccessRadio = getByLabelText(i18nStrings.Clusters.radioButtonLabels.basicAccess);
    const noCredentialRadio = getByLabelText(i18nStrings.Clusters.radioButtonLabels.noCredential);

    expect(basicAccessRadio).toBeChecked();
    expect(noCredentialRadio).not.toBeChecked();
  });
});

==> sagemaker_jupyterlab_emr_extension-0.4.0.tar.gz: sagemaker_jupyterlab_emr_extension-0.4.0/src/components/__tests__/SelectAuthType.spec.tsx <==
import React from 'react';
import { render } from '@testing-library/react';
import '@testing-library/jest-dom/extend-expect';
import { SelectAuthType, SelectAuthTypeProps } from '../SelectAuthType';
import { i18nStrings } from '../../constants/i18n';
import { JupyterFrontEnd } from '@jupyterlab/application';

// Mock the necessary props and functions
const app = null as unknown as JupyterFrontEnd;

jest.mock('../../utils/ConnectClusterUtils', () => ({ openSelectRuntimeExecRole: jest.fn() }));

const mockProps: SelectAuthTypeProps = {
  onCloseModal: jest.fn(),
  selectedCluster: { id: 'id', status: {} },
  emrConnectRoleData: { CallerAccountId: 'cluster-account-id', EmrAssumableRoleArns: [], EmrExecutionRoleArns: [] },
  app: app,
};

describe('SelectAuthType', () => {
  it('renders component with default auth type', () => {
    const { getByLabelText } = render(<SelectAuthType {...mockProps} />);

    // Ensure that the component renders with default auth type 'Basic_Access'
    expect(getByLabelText(i18nStrings.Clusters.radioButtonLabels.basicAccess)).toBeInTheDocument();
    expect(getByLabelText(i18nStrings.Clusters.radioButtonLabels.RBAC)).toBeInTheDocument();
    expect(getByLabelText(i18nStrings.Clusters.radioButtonLabels.noCredential)).toBeInTheDocument();
    expect(getByLabelText(i18nStrings.Clusters.radioButtonLabels.kerberos)).toBeInTheDocument();

    // basic access will be checked by default
    const basicAccessRadio = getByLabelText(i18nStrings.Clusters.radioButtonLabels.basicAccess);
    expect(basicAccessRadio).toBeChecked();
  });
});
